# ResearchResourceItemV30

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**resource_name** | **str** |  | [optional] 
**resource_type** | **str** |  | [optional] 
**hosts** | [**ResearchResourceHostsV30**](ResearchResourceHostsV30.md) |  | [optional] 
**external_ids** | [**ExternalIDsV30**](ExternalIDsV30.md) |  | [optional] 
**url** | [**UrlV30**](UrlV30.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

